@@ -14,7 +14,7 @@ def validate_config(config):
             raise ValueError(f'Values to {_config} should be a list of files')
         for file in _config_data:
             if not os.path.exists(file):
-                raise FileNotFoundError(file)
+                logging.warning(f"file '{file}' not found")
 
 
 def check_against_htpasswd(htpasswd_file, username, password):
