@@ -43,9 +43,9 @@ class AuthXMiddleware:
             if scope['path'] in self._known_paths.keys():
                 if not utils.validator(condition=self._known_paths[scope['path']], config=scope.get('authx', {})):
                     response = JSONResponse({'message': 'unauthorized'}, status_code=401)
-                    await response(scope, receive, send)
-            else:
-                await self._app(scope, receive, send)
+                    return await response(scope, receive, send)
+
+            await self._app(scope, receive, send)
 
         except InvalidToken as e:
             response = JSONResponse({'message': str(e)}, status_code=401)
